==========
pywe-jssdk
==========

Wechat JSSDK Module for Python.

Installation
============

::

    pip install pywe-jssdk


Usage
=====

::

    from pywe_jssdk import jsapi_signature_params


Method
======

::

    def jsapi_signature_params(appid=None, secret=None, url=None, storage=None):

